@@ -75,31 +75,42 @@ OC.L10N.register(
     "Go to the \"{dir}\" directory" : "Оди до \"{dir}\" папката",
     "Current directory path" : "Патека до оваа папка",
     "Your have used your space quota and cannot upload files anymore" : "Го имате искористено лимитот на просторот за прикачување и повеќе неможете да прикачувате датотеки",
+    "You do not have permission to upload or create files here." : "Немате дозвола да прикачувате или да креирате датотеки овде",
     "Drag and drop files here to upload" : "Повлечи и испушти датотеки за прикачување",
     "Favorite" : "Омилени",
     "Back" : "Назад",
+    "File is loading" : "Датотеката се вчитува",
+    "Folder is loading" : "Папката се вчитува",
     "Filename" : "Име на датотека",
     "Folder name" : "Име на папка",
     "This node is unavailable" : "Нодот е недостапен",
+    "Another entry with the same name already exists." : "Друг запис со исто име веќе постои.",
+    "Invalid filename." : "Невалидно име.",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Преименувано \"{oldName}\" во \"{newName}\"",
     "Rename file" : "Преименувај датотека",
     "Folder" : "Папка",
+    "Unknown file type" : "Непознат тип на датотека",
     "Pending" : "Чека",
+    "Unknown date" : "Непознат датум",
     "Clear filter" : "Исчисти филтри",
     "Modified" : "Променето",
+    "Search everywhere" : "Барај насекаде",
     "Type" : "Вид",
+    "Active filters" : "Активни филтри",
+    "Remove filter" : "Острани филтер",
     "Total rows summary" : "Резиме на вкупно редови",
     "Name" : "Име",
+    "File type" : "Вид на датотека",
     "Size" : "Големина",
-    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" сериската акција е успешно извршена",
-    "\"{displayName}\" action failed" : "\"{displayName}\" акцијата не успеа",
     "Actions" : "Акции",
     "(selected)" : "(означени)",
     "List of files and folders." : "Листа на датотеки и папки.",
+    "You have used your space quota and cannot upload files anymore." : "Го имате искористено лимитот на просторот за прикачување и повеќе неможете да прикачувате датотеки.",
     "Column headers with buttons are sortable." : "Насловите на колоните со копчиња се сортираат.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Оваа листа не е целосно прикажана поради заштеда на перформанси. Датотеките ќе се прикажуваат додека се движите низ листата.",
     "File not found" : "Датотеката не е пронајдена",
-    "{count} selected" : "{count} селектирани",
+    "_{count} selected_::_{count} selected_" : ["{count} означена","{count} означени"],
+    "Search scope options" : "Параметри за опсег на пребарување",
     "{usedQuotaByte} used" : "искористено {usedQuotaByte}",
     "{used} of {quota} used" : "Искористени {used} од {quota}",
     "{relative}% used" : "искористено {relative}% ",
@@ -110,6 +121,8 @@ OC.L10N.register(
     "Create new folder" : "Креирај нова папка",
     "This name is already in use." : "Името е веќе во употреба.",
     "Create" : "Креирај",
+    "Fill template fields" : "Пополни ги полињата за шаблон",
+    "Submitting fields …" : "Испраќање полиња ...",
     "Submit" : "Испрати",
     "Choose a file or folder to transfer" : "Избери датотека или папка за трансфер",
     "Transfer" : "Трансфер",
@@ -122,6 +135,13 @@ OC.L10N.register(
     "Choose file or folder to transfer" : "Избери датотека или папка за трансфер",
     "Change" : "Измени",
     "New owner" : "Нов сопственик",
+    "Use {new}" : "Користи {new}",
+    "Remove extension" : "Отстрани екстензија",
+    "Change file extension" : "Промени екстензија",
+    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Промена на екстензијата од \"{old}\" во \"{new}\" може да ја јаправи датотеката нечитлива.",
+    "Removing the file extension \"{old}\" may render the file unreadable." : "Остранување на екстензијата \"{old}\" може да ја направи датотеката нечитлива.",
+    "Adding the file extension \"{new}\" may render the file unreadable." : "Додавање на екстензијата \"{new}\" може да ја направи датотеката нечитлива.",
+    "Do not show this dialog again." : "Не го прикажувај овој дијалог повторно.",
     "Select file or folder to link to" : "Изберете датотека или папка за линк до",
     "Choose {file}" : "Избери {file}",
     "Share" : "Сподели",
@@ -129,11 +149,13 @@ OC.L10N.register(
     "Shared" : "Споделено",
     "Switch to list view" : "Прикажи поглед во листа",
     "Switch to grid view" : "Прикажи поглед во мрежа",
+    "The file could not be found" : "Датотеката неможе да биде пројандена",
+    "Upload was cancelled by user" : "Прикачувањето беше откажано од корисникот",
     "Not enough free space" : "Нема доволно слободен простор",
     "Operation is blocked by access control" : "Операцијата е блокирана од контролата на пристап",
     "Error during upload: {message}" : "Грешка при прикачување: {message}",
+    "Error during upload, status code {status}" : "Грешка при прикачување, статус код {status}",
     "Unknown error during upload" : "Непозната грешка при прикачување",
-    "\"{displayName}\" action executed successfully" : "\"{displayName}\" акцијата е успешно извршена",
     "Loading current folder" : "Вчитување на моменталната папка",
     "Retry" : "Обидете се повторно",
     "No files in here" : "Тука нема датотеки",
@@ -144,25 +166,40 @@ OC.L10N.register(
     "Your files" : "Ваши датотеки",
     "Open in files" : "Отвори во датотеките",
     "File cannot be accessed" : "Неможе да се пристапи до датотеката",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Датотеката не може да се пронајде или немате дозволи за да ја видите. Побарајте од испраќачот да ја сподели.",
+    "No search results for “{query}”" : "Нема резултати од пребарувањето за \"{query}\"",
+    "Search for files" : "Пребарај датотеки",
     "Clipboard is not available" : "Клипбордот не е достапен",
-    "WebDAV URL copied to clipboard" : "CalDAV линкот е копиран",
+    "General" : "Општо",
+    "Default view" : "Стандарден поглед",
+    "All files" : "Сите датотеки",
+    "Personal files" : "Лични датотеки",
     "Sort favorites first" : "Прво омилените",
+    "Sort folders before files" : "Подреди ги папките пред датотеките",
+    "Appearance" : "Изглед",
     "Show hidden files" : "Прикажи сокриени датотеки",
+    "Show file type column" : "Прикажи колона за тип на датотека",
     "Crop image previews" : "Исечи ја сликата за преглед",
-    "Enable the grid view" : "Овозможи поглед во мрежа",
     "Additional settings" : "Дополнителни параметри",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV адреса",
-    "Copy to clipboard" : "Копирај во клипборд",
-    "Use this address to access your Files via WebDAV" : "Користи ја оваа адреса за пристап до вашите датотеки преку WebDAV",
-    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ако имате овозможено 2FA, мора да креирате и користите нова лозинка за апликација со кликнување овде.",
+    "Copy" : "Копирај",
     "Warnings" : "Предупредувања",
     "Keyboard shortcuts" : "Кратенки преку тастатура",
-    "Rename a file" : "Преименувај датотека",
-    "Delete a file" : "Избриши датотека",
+    "File actions" : "Акции со датотеки",
+    "Rename" : "Преименувај",
+    "Delete" : "Избриши",
+    "Manage tags" : "Уреди ги ознаките",
+    "Selection" : "Селектирање",
+    "Select all files" : "Селектирај ги сите датотеки",
+    "Deselect all" : "Одселектирај се",
     "Navigation" : "Навигација",
-    "View" : "Погледни",
+    "View" : "Поглед",
+    "Toggle grid view" : "Промена во мрежа",
+    "Show those shortcuts" : "Покажи ги овие кратенки",
     "You" : "Вас",
+    "Shared multiple times with different people" : "Споделено повеќе пати со различни луѓе",
+    "Unable to change the favorite state of the file" : "Неможе да се промени статусот на омимени на датотеката",
     "Error while loading the file data" : "Грешка при вчитување на податоците од датотеката",
     "Owner" : "Сопственик",
     "Remove from favorites" : "Отстрани од фаворити",
@@ -176,16 +213,21 @@ OC.L10N.register(
     "Save as {displayName}" : "Зачувај како {displayName}",
     "Save as …" : "Зачувај како ...",
     "Converting files …" : "Конвертирање датотеки …",
-    "Deletion cancelled" : "Бришењето е откажано",
+    "Leave this share" : "Напушти го ова споделување",
+    "Leave these shares" : "Напушти ги овие споделувања",
     "Disconnect storage" : "Исклучи складиште",
     "Delete permanently" : "Избриши",
     "Delete file" : "Избриши датотека",
     "Delete files" : "Избриши датотеки",
     "Delete folder" : "Избриши папка",
     "Delete folders" : "Избриши папки",
-    "Delete" : "Избриши",
+    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Сакате да избришете {count} датотека","Сакате да избришете {count} датотеки"],
+    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Сакате да избришете {count} датотека","Сакате да избришете {count} датотеки"],
     "Confirm deletion" : "Потврди бришење",
     "Cancel" : "Откажи",
+    "Download" : "Преземи",
+    "Destination is not a folder" : "Дестинацијата не е папка",
+    "This file/folder is already in that directory" : "Оваа папка/датотека се наоѓа веќе во таа папка",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Неможете да преместите датотека/папка во себеси или во подпапка во себеси",
     "(copy)" : "(копирај)",
     "(copy %n)" : "(копирај %n)",
@@ -194,18 +236,15 @@ OC.L10N.register(
     "The file does not exist anymore" : "Датотеката не постои",
     "Choose destination" : "Избери дестинација",
     "Copy to {target}" : "Копирај во {target}",
-    "Copy" : "Копирај",
     "Move to {target}" : "Премести во {target}",
     "Move" : "Премести",
     "Move or copy" : "Премести или копирај",
-    "Cancelled move or copy operation" : "Откажана операција на копирање или преместување",
     "Open folder {displayName}" : "Отвори папка {displayName}",
     "Open in Files" : "Отвори во датотеките",
     "Open locally" : "Отвори локално",
     "Failed to redirect to client" : "Неуспешно пренасочување кон клиентот",
     "Open file locally" : "Отвори ја датотеката локално",
-    "Rename" : "Преименувај",
-    "Open details" : "Отвори детали",
+    "Details" : "Детали:",
     "View in folder" : "Погледни во папката",
     "Today" : "Денес",
     "Last 7 days" : "Предходни 7 дена",
@@ -213,35 +252,53 @@ OC.L10N.register(
     "This year ({year})" : "Оваа година ({year})",
     "Last year ({year})" : "Минатата година ({year})",
     "Documents" : "Документи",
+    "Spreadsheets" : "Табели",
+    "Presentations" : "Презентации",
+    "PDFs" : "PDF-и",
     "Folders" : "Папки",
     "Audio" : "Аудио",
+    "Images" : "Слики",
     "Videos" : "Видеа",
     "Created new folder \"{name}\"" : "Креирана нова папка \"{name}\"",
     "Unable to initialize the templates directory" : "Не може да се иницијализира папка за шаблони",
     "Create templates folder" : "Креирај папка за шаблони",
     "Templates" : "Шаблони",
+    "New template folder" : "Нова папка за шаблони",
+    "In folder" : "Во папка",
+    "Search in folder: {folder}" : "Барај во папка: {folder}",
     "One of the dropped files could not be processed" : "Една од испуштените датотеки неможе да се процесоира",
+    "Unable to create the directory {directory}" : "Неможе да се креира папка {directory}",
+    "Some files could not be uploaded" : "Некој датотеки неможат да се прикачат",
+    "Files uploaded successfully" : "Успешно прикачени датотеки",
     "Some files could not be moved" : "Некои датотеки не можат да се преместат",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Неможе да се преименува \"{oldName}\", не постои повеќе",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Името \"{newName}\" веќе се користи во папката \"{dir}\". Ве молиме изберете друго име.",
+    "Could not rename \"{oldName}\"" : "Неможе да се преименува \"{oldName}\"",
     "This operation is forbidden" : "Операцијата не е дозволена",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Овој директориум е недостапен, ве молиме проверете ги логовите или контактирајте со администраторот",
     "Storage is temporarily not available" : "Складиштето моментално не е достапно",
+    "Unexpected error: {error}" : "Неочекувана грешка: {error}",
     "_%n file_::_%n files_" : ["%n датотека","%n датотеки"],
     "_%n folder_::_%n folders_" : ["%n папка","%n папки"],
+    "Filename must not be empty." : "Името на датотеката не може да биде празно.",
+    "\"{char}\" is not allowed inside a filename." : "\"{char}\" не е дозволен во името на датотеката.",
+    "\"{segment}\" is a reserved name and not allowed for filenames." : "\"{segment}\" е резервирано име и не е дозволено во името на датотеката.",
+    "\"{extension}\" is not an allowed filetype." : "\"{extension}\" не е дозволен вид на датотека.",
+    "Filenames must not end with \"{extension}\"." : "Името неможе да завршува со \"{extension}\".",
+    "List of favorite files and folders." : "Листа на омилени датотеки и папки.",
     "No favorites yet" : "Сеуште нема фаворити",
     "Files and folders you mark as favorite will show up here" : "Датотеките и папките кои ќе ги означите како чести, ќе се појават тука",
-    "All files" : "Сите датотеки",
     "List of your files and folders." : "Листа на вашите датотеки и папки.",
-    "All folders" : "Сите папки",
+    "No personal files found" : "Не се пронајдени лични датотеки ",
     "Recent" : "Неодамнешни",
     "List of recently modified files and folders." : "Листа на скоро изменети датотеки и папки.",
     "No recently modified files" : "Нема скоро изменети датотеки",
     "Files and folders you recently modified will show up here." : "Датотеките и папките кои скоро ќе ги измените ќе се појават тука.",
+    "Search" : "Барај",
     "No entries found in this folder" : "Нема ништо во оваа папка",
     "Select all" : "Избери се",
     "Upload too large" : "Фајлот кој се вчитува е преголем",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Датотеките кои се обидувате да ги подигнете ја надминуваат максималната големина за подигнување датотеки на овој сервер.",
     "File could not be found" : "Неможе да се пронајде датотеката",
-    "Download" : "Преземи",
     "Show list view" : "Прикажи поглед во листа",
     "Show grid view" : "Прикажи поглед во мрежа",
     "Close" : "Затвори",
@@ -266,12 +323,12 @@ OC.L10N.register(
     "Edit locally" : "Уреди локално",
     "Open" : "Отвори",
     "Could not load info for file \"{file}\"" : "Неможе да се вчитаат информации за датотеката \"{file}\"",
-    "Details" : "Детали:",
     "Please select tag(s) to add to the selection" : "Избери ознаки за одбележаното",
     "Apply tag(s) to selection" : "Примени ознаки на обележаните",
     "Select directory \"{dirName}\"" : "Избери папка \"{dirName}\"",
     "Select file \"{fileName}\"" : "Избери датотека \"{fileName}\"",
     "Unable to determine date" : "Неможе да се одреди датумот",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Овој директориум е недостапен, ве молиме проверете ги логовите или контактирајте со администраторот",
     "Could not move \"{file}\", target exists" : "Не може да се премести \"{file}\", веќе постои",
     "Could not move \"{file}\"" : "Не може да се премести \"{file}\"",
     "copy" : "копирај",
@@ -280,9 +337,6 @@ OC.L10N.register(
     "Copied {origin} inside {destination}" : "Копирана {origin} во {destination}",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "Копирана {origin} и {nbfiles} други датотеки во {destination}",
     "{newName} already exists" : "{newName} веќе постои",
-    "Could not rename \"{fileName}\", it does not exist any more" : "Неможе да се преименува \"{fileName}\", датотеката не постои",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Името \"{targetName}\" веќе се користи во папката \"{dir}\". Ве молиме изберете друго име.",
-    "Could not rename \"{fileName}\"" : "Неможе да се преименува \"{fileName}\"",
     "Could not create file \"{file}\"" : "Неможе да се креира датотека \"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "Неможе да се креира датотека \"{file}\" бидејќи веќе постои",
     "Could not create folder \"{dir}\" because it already exists" : "Неможе да се креира папка \"{dir}\" бидејќи веќе постои",
@@ -294,7 +348,7 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["вклучувајќи %n скриена","вклучувајќи %n скриени"],
     "You do not have permission to upload or create files here" : "Немате дозвола да прикачувате или да креирате датотеки овде",
     "_Uploading %n file_::_Uploading %n files_" : ["Прикачување %n датотека","Прикачување на %n датотеки"],
-    "New" : "Ново",
+    "New" : "Нов/a",
     "New file/folder menu" : "Мени Нова датотека/папка",
     "Select file range" : "Избери опсег на датотеки",
     "{used}%" : "{used}%",
@@ -319,13 +373,49 @@ OC.L10N.register(
     "Upload file" : "Прикачи датотека",
     "An error occurred while trying to update the tags" : "Се случи грешка додека се обидувавте да ги освежите таговите",
     "Upload (max. %s)" : "Префрлање (макс. %s)",
+    "\"{displayName}\" action executed successfully" : "\"{displayName}\" акцијата е успешно извршена",
+    "\"{displayName}\" action failed" : "\"{displayName}\" акцијата не успеа",
+    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" сериската акција е успешно извршена",
+    "Filter filenames…" : "Филтрирај имиња на датотеки ...",
+    "WebDAV URL copied to clipboard" : "CalDAV линкот е копиран",
+    "Enable the grid view" : "Овозможи поглед во мрежа",
+    "Enable folder tree" : "Овозможи поглед на дрво",
+    "Copy to clipboard" : "Копирај во клипборд",
+    "Use this address to access your Files via WebDAV" : "Користи ја оваа адреса за пристап до вашите датотеки преку WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ако имате овозможено 2FA, мора да креирате и користите нова лозинка за апликација со кликнување овде.",
+    "Deletion cancelled" : "Бришењето е откажано",
+    "Cancelled move or copy operation" : "Откажана операција на копирање или преместување",
+    "Open details" : "Отвори детали",
+    "Photos and images" : "Фотографии и слики",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} папка","{folderCount} папки"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} датотека","{fileCount} датотеки"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 датотека и {folderCount} папки","1 датотека и {folderCount} папки"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} датотека и 1 папка","{fileCount} датотеки и 1 папка"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} датотеки и {folderCount} папки",
-    "Personal Files" : "Персонални датотеки",
+    "All folders" : "Сите папки",
+    "Personal Files" : "Лични датотеки",
     "Text file" : "Текстуална датотека",
-    "New text file.txt" : "Нова текстуална датотека file.txt"
+    "New text file.txt" : "Нова текстуална датотека file.txt",
+    "%1$s (renamed)" : "%1$s (преименувано)",
+    "renamed file" : "преименувана датотека",
+    "Filter file names …" : "Филтрирај имиња на датотеки ...",
+    "Prevent warning dialogs from open or reenable them." : "Спречете ги дијалозите за предупредување да се отвораат или повторно овозможете ги.",
+    "Show a warning dialog when changing a file extension." : "Прикажи дијалог за предупредување при промена на екстензија на датотека.",
+    "Speed up your Files experience with these quick shortcuts." : "Забрзајте го вашето искуство со овие брзи кратенки.",
+    "Open the actions menu for a file" : "Отвори Мени со акции за датотека",
+    "Rename a file" : "Преименувај датотека",
+    "Delete a file" : "Избриши датотека",
+    "Favorite or remove a file from favorites" : "Додади или острани од омилени",
+    "Manage tags for a file" : "Управувај со ознаки за датотека",
+    "Deselect all files" : "Деселектирај ги сите датотеки",
+    "Select or deselect a file" : "Селектирај или деселектирај датотека",
+    "Select a range of files" : "Селектирај опсег на датотеки",
+    "Navigate to the parent folder" : "Врати се до предходната папка",
+    "Navigate to the file above" : "Оди до датотека горе",
+    "Navigate to the file below" : "Оди до датотека доле",
+    "Navigate to the file on the left (in grid mode)" : "Оди до датотека лево (само во мрежен приказ)",
+    "Navigate to the file on the right (in grid mode)" : "Оди до датотека десно (само во мрежен приказ)",
+    "Toggle the grid view" : "Вклучи/исклучи мрежен приказ",
+    "Open the sidebar for a file" : "Отвори странична лента за датотека"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
