@@ -1,6 +1,7 @@
 OC.L10N.register(
     "photos",
     {
+    "Public link" : "Liga pública",
     "Photos" : "Fotos",
     "Videos" : "Videos",
     "Folders" : "Carpetas",
@@ -9,9 +10,14 @@ OC.L10N.register(
     "Tags" : "Etiquetas",
     "Back" : "Atrás",
     "Save" : "Guardar",
+    "Shared by" : "Compartido por",
+    "Group" : "Grupo",
     "Favorite" : "Favorito",
+    "Go back" : "Regresar",
+    "Dates" : "Fechas",
+    "Home" : "Inicio",
     "Remove from favorites" : "Eliminar de favoritos",
-    "Add" : "Agregar",
-    "Settings" : "Configuraciones "
+    "Details" : "Detalles",
+    "Add" : "Agregar"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
