@@ -21,9 +21,6 @@ OC.L10N.register(
     "Mark selection as favorite" : "Seçilmişleri sık kullanılanlara ekle",
     "Add selection to favorites" : "Seçilmişleri sık kullanılanlara ekle",
     "Remove selection from favorites" : "Seçilmişleri sık kullanılanlardan çıkar",
-    "This name is already in use." : "Bu ad zaten kullanılıyor.",
-    "\"{char}\" is not allowed inside a filename." : "Dosya adlarında \"{char}\" kullanılamaz.",
-    "Invalid filename." : "Dosya adı geçersiz.",
     "Name of the album" : "Albümün adı",
     "Location of the album" : "Albümün konumu",
     "Back" : "Geri",
@@ -42,6 +39,8 @@ OC.L10N.register(
     "Add people or groups who can edit your album" : "Albümünüzü düzenleyebilecek kişi ya da grupları ekleyin",
     "Search people or groups" : "Kişi ya da grup arama",
     "No recommendations. Start typing." : "Herhangi bir öneri yok. Yazmaya başlayın.",
+    "Group" : "Grup",
+    "Remove {collaboratorLabel} from the collaborators list" : "{collaboratorLabel} kullanıcısını katılımcı listesinden çıkar",
     "Copy the public link" : "Herkese açık bağlantıyı kopyala",
     "Public link copied!" : "Herkese açık bağlantı kopyalandı!",
     "Copy public link" : "Herkese açık bağlantıyı kopyala",
@@ -61,10 +60,9 @@ OC.L10N.register(
     "Select image {imageName}" : "{imageName} görselini seç",
     "Open the \"{name}\" folder" : "\"{name}\" klasörünü aç",
     "Go back" : "Geri dön",
-    "Select a custom date range" : "Bir özel tarih aralığı seçin",
-    "Select a date range" : "Bir tarih aralığı seçin",
     "Date range" : "Tarih aralığı",
-    "Select filters" : "Süzgeçleri seçin",
+    "Select a date range" : "Bir tarih aralığı seçin",
+    "Select places" : "Yerleri seçin",
     "Dates" : "Tarihler",
     "Jump to specific date in list" : "Listede belirli bir tarihe git",
     "Jump to {date}" : "{date} tarihine git",
@@ -90,6 +88,7 @@ OC.L10N.register(
     "Choose the folder where photos and albums are uploaded to." : "Fotoğraf ve albümlerin yükleneceği klasörü seçin.",
     "_%n photo_::_%n photos_" : ["%n fotoğraf","%n fotoğraf"],
     "Unselect all" : "Tümünü bırak",
+    "Toggle filter" : "Süzgeci aç/kapat",
     "Add photos to this album" : "Bu albüme fotoğraflar ekle",
     "Manage collaborators for this album" : "Bu albümün katılımcılarını yönet",
     "Open actions menu" : "İşlemler menüsünü aç",
@@ -119,7 +118,7 @@ OC.L10N.register(
     "This might take some time depending on the size of your photo library." : "Bu işlemin tamamlanması fotoğraf arşivinizin boyutuna bağlı olarak biraz zaman alabilir.",
     "Recognized people will show up here" : "Tanınan kişiler burada görüntülenir",
     "This folder does not exist" : "Bu klasör bulunamadı",
-    "Loading folders…" : "Klasörler yükleniyor…",
+    "Loading folders …" : "Klasörler yükleniyor…",
     "No photos in here" : "Burada herhangi bir fotoğraf yok",
     "Taken on {date} at {time}" : "{date} tarihinde {time} saatinde çekilmiş",
     "This place does not have any photos or videos yet!" : "Bu yerde henüz bir fotoğraf ya da görüntü yok!",
@@ -151,9 +150,6 @@ OC.L10N.register(
     "Tagged photos" : "Etiketlenmiş fotoğraflar",
     "Tagged photo {title}" : "{title} etiketlenmiş fotoğraf",
     "{title}'s face" : "{title} yüzü",
-    "Last week" : "Önceki hafta",
-    "Last Month" : "Önceki ay",
-    "Custom…" : "Özel…",
     "{startDate} to {endDate}" : "{startDate} - {endDate}",
     "Details" : "Ayrıntılar",
     "Failed to add {fileBaseName} to collection {collectionFileName}" : "{fileBaseName}, {collectionFileName} derlemesine eklenemedi",
@@ -171,11 +167,8 @@ OC.L10N.register(
     "Failed to set favorite state for {fileId}" : "{fileId} için sık kullanılan durumu ayarlanamadı",
     "Failed to set favorite state for {fileName}" : "{fileName} için sık kullanılan durumu ayarlanamadı",
     "Could not load photos folder" : "Fotoğraflar klasörü yüklenemedi",
-    "Group" : "Grup",
-    "Remove {collaboratorLabel} from the collaborators list" : "{collaboratorLabel} kullanıcısını katılımcı listesinden çıkar",
     "Back to {folder}" : "{folder} klasörüne geri dön",
     "Share this folder" : "Bu klasörü paylaş",
-    "Loading folders …" : "Klasörler yükleniyor…",
     "One of the source folders does not exists" : "Kaynak klasörlerden biri bulunamadı",
     "Add" : "Ekle"
 },
