@@ -108,7 +108,7 @@ OC.L10N.register(
     "Administration" : "Alministración",
     "Users" : "Usuarios",
     "Additional settings" : "Configuración adicional",
-    "Artificial Intelligence" : "Intelixencia artificial",
+    "Assistant" : "Asistente",
     "Administration privileges" : "Privilexos de l'alministración",
     "Groupware" : "Trabayu en grupu",
     "Overview" : "Vista xeneral",
@@ -118,6 +118,7 @@ OC.L10N.register(
     "Calendar" : "Calendariu",
     "Personal info" : "Información personal",
     "Mobile & desktop" : "Móvil y ordenador",
+    "Artificial Intelligence" : "Intelixencia artificial",
     "Email server" : "Sirvidor de corréu electrónicu",
     "Background jobs" : "Trabayos en segundu planu",
     "Unlimited" : "Ensin llende",
@@ -201,11 +202,11 @@ OC.L10N.register(
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "La base de datos nun s'executa col nivel d'aislamientu de transaiciones «READ COMMITTED». Esta transaición pue causar problemes cuando s'executen múltiples aiciones en paralelo.",
     "Profile information" : "Información del perfil",
     "Nextcloud settings" : "Configuración de Nextcloud",
-    "Task:" : "Xera:",
     "Enable" : "Activar",
     "Machine translation" : "Traducción per ordenador",
     "Image generation" : "Xeneración d'imáxenes",
     "Text processing" : "Procesamientu de testos",
+    "Task:" : "Xera:",
     "Here you can decide which group can access certain sections of the administration settings." : "Equí pues decidir qué grupu pue acceder a ciertes seiciones de la configuración d'alministración.",
     "Unable to modify setting" : "Nun ye posible modificar la opción",
     "None" : "Nada",
@@ -219,6 +220,7 @@ OC.L10N.register(
     "Two-factor authentication is not enforced for members of the following groups." : "L'autenticación en dos pasos nun ye obligatoria pa los miembros de los grupos siguientes.",
     "Excluded groups" : "Grupos escluyíos",
     "Save changes" : "Guardar los cambeos",
+    "Default" : "Por defeutu",
     "Remove" : "Quitar",
     "Featured" : "Destacada",
     "Disable all" : "Desactivar too",
@@ -265,7 +267,7 @@ OC.L10N.register(
     "Resources" : "Recursos",
     "Documentation" : "Documentación",
     "Interact" : "Interactuar",
-    "Report a bug" : "Informar d'un fallju",
+    "Report a bug" : "Informar d'un fallu",
     "Request feature" : "Pidir una función",
     "Ask questions or discuss" : "Entrugar o discutir",
     "Rate" : "Valorar",
