@@ -230,7 +230,6 @@ OC.L10N.register(
     "Federated user" : "Федерисани корисник",
     "user@your-nextcloud.org" : "korisnik@vas-nextcloud.org",
     "Create share" : "Kreirajte deljenje",
-    "Direct link copied to clipboard" : "Директни линк је копиран у клипборд",
     "Please copy the link manually:" : "Молимо вас да ручно корпирате линк:",
     "Custom date range" : "Произвољни опсег датума",
     "Pick start date" : "Изаберите почетни датум",
@@ -328,6 +327,11 @@ OC.L10N.register(
     "Login form is disabled." : "Форма за пријаву је искључена.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud формулар за пријаву је искључен. Ако је доступна, користите неку другу могућност пријаве, или се обратите администрацији.",
     "More actions" : "Још акција",
+    "User menu" : "Кориснички мени",
+    "You will be identified as {user} by the account owner." : "Власник налога ће вас идентификовати као {user}.",
+    "You are currently not identified." : "Тренутно нисте идентификовани.",
+    "Set public name" : "Постави јавно име",
+    "Change public name" : "Измени јавно име",
     "Password is too weak" : "Лозинка је сувише слаба",
     "Password is weak" : "Лозинка је слаба",
     "Password is average" : "Лозинка је просечна",
@@ -421,6 +425,7 @@ OC.L10N.register(
     "Admin" : "Администрација",
     "Help" : "Помоћ",
     "Access forbidden" : "Забрањен приступ",
+    "You are not allowed to access this page." : "Није вам дозвољено да приступите овој страници.",
     "Back to %s" : "Назад на %s",
     "Page not found" : "Страна није нађена",
     "The page could not be found on the server or you may not be allowed to view it." : "Страница не може да се пронађе на серверу или можда немате права да је видите.",
@@ -521,6 +526,7 @@ OC.L10N.register(
     "Toggle password visibility" : "Укључи/искључи видљивост лозинке",
     "Configure the database" : "Подешавање базе",
     "Only %s is available." : "Само %s је доступна.",
-    "Database account" : "Налог базе података"
+    "Database account" : "Налог базе података",
+    "Direct link copied to clipboard" : "Директни линк је копиран у клипборд"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
