@@ -38,7 +38,7 @@ OC.L10N.register(
     "Server version %s or higher is required." : "サーバーの %s よりも高いバージョンが必要です。",
     "Server version %s or lower is required." : "サーバーの %s よりも低いバージョンが必要です。",
     "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "この設定にアクセスするには、ログインしたアカウントが管理者、サブ管理者、または特別な権利を持っている必要があります。",
-    "Your current IP address doesn’t allow you to perform admin actions" : "現在のIPアドレスでは管理アクションを実行できません",
+    "Your current IP address doesn't allow you to perform admin actions" : "現在のIPアドレスでは管理アクションを実行できません",
     "Logged in account must be an admin or sub admin" : "ログインアカウントは管理者またはサブ管理者である必要があります",
     "Logged in account must be an admin" : "ログインアカウントは管理者である必要があります",
     "Wiping of device %s has started" : "端末%sのワイプを開始しました。",
@@ -59,6 +59,11 @@ OC.L10N.register(
     "Avatar image is not square" : "アバター画像が正方形ではありません",
     "Files" : "ファイル",
     "View profile" : "プロフィールを表示",
+    "same time" : "同時",
+    "_%nh_::_%nh_" : ["%n時間"],
+    "_%nm_::_%nm_" : ["%n分"],
+    "%s ahead" : "%s先",
+    "%s behind" : "%s遅れ",
     "Local time: %s" : "現地時間: %s",
     "today" : "今日",
     "tomorrow" : "明日",
@@ -81,7 +86,15 @@ OC.L10N.register(
     "seconds ago" : "数秒前",
     "Empty file" : "空白のファイル",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "ID: %sのモジュールは存在しません。アプリ設定で有効にするか、管理者に問い合わせてください。",
+    "No file conversion providers available" : "ファイル変換プロバイダーは利用できません",
+    "File is too large to convert" : "ファイルが大きすぎて変換できません",
+    "Destination does not match conversion extension" : "変換先の拡張子が一致しません",
+    "Could not convert file" : "ファイルを変換できませんでした",
+    "Destination does not exist" : "宛先が存在しません",
+    "Destination is not creatable" : "宛先は作成できません",
     "Dot files are not allowed" : "隠しファイルは許可されていません",
+    "%1$s (renamed)" : "%1$s (リネーム済み)",
+    "renamed file" : "リネーム済みファイル",
     "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\"は禁止されているファイル名またはフォルダー名です。",
     "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\"は、ファイル名やフォルダー名には使用できない接頭辞です。",
     "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\"はファイル名やフォルダー名の中に入れることはできません。",
@@ -92,6 +105,13 @@ OC.L10N.register(
     "Invalid path" : "パスが無効",
     "Failed to create file from template" : "テンプレートからファイルを作成できませんでした",
     "Templates" : "テンプレート",
+    "Storage %s cannot be moved" : "ストレージ%sは移動できません",
+    "Moving a share (%s) into a shared folder is not allowed" : "共有(%s)を共有フォルダに移動することは許可されていません",
+    "Moving a storage (%s) into a shared folder is not allowed" : "ストレージ(%s)を共有フォルダに移動することは許可されていません",
+    "Moving a share (%s) into another share (%s) is not allowed" : "共有 (%s) を別の共有 (%s) に移動することは許可されていません",
+    "Moving a share (%s) into another storage (%s) is not allowed" : "共有(%s)を別のストレージ(%s)に移動することは許可されていません",
+    "Moving a storage (%s) into a share (%s) is not allowed" : "ストレージ(%s)を共有(%s)に移動することは許可されていません",
+    "Moving a storage (%s) into another storage (%s) is not allowed" : "ストレージ(%s)を別のストレージ(%s)に移動することは許可されていません。",
     "Path contains invalid segments" : "パスに無効なセグメントが含まれています",
     "Filename is a reserved word" : "ファイル名が予約された単語です",
     "Filename contains at least one invalid character" : "ファイル名に使用できない文字が含まれています",
@@ -124,8 +144,9 @@ OC.L10N.register(
     "About" : "詳細",
     "Display name" : "表示名",
     "Headline" : "見出し",
-    "Organisation" : "組織",
+    "Organization" : "共同作業",
     "Role" : "ロール",
+    "Pronouns" : "代名詞",
     "Unknown account" : "不明なアカウント",
     "Additional settings" : "追加設定",
     "Enter the database Login and name for %s" : "%s のデータベース名とログイン名を入力してください",
@@ -137,7 +158,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Oracleへの接続が確立できませんでした。",
     "Oracle Login and/or password not valid" : "Oracleのログイン名またはパスワードが有効ではありません",
     "PostgreSQL Login and/or password not valid" : "PostgreSQLのログイン名またはパスワードが有効ではありません",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X では、サポートされていません。このOSでは、%sは正常に動作しないかもしれません。ご自身の責任においてご利用ください。",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X では、サポートされていません。このOSでは、%sは正常に動作しないかもしれません。ご自身の責任においてご利用ください。",
     "For the best results, please consider using a GNU/Linux server instead." : "最も良い方法としては、代わりにGNU/Linuxサーバーを利用することをご検討ください。",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "このインスタンス %s は、32bit PHP 環境で動作しており、php.ini に open_basedir が設定されているようです。4GB以上のファイルで問題が発生するため、この設定を利用しないことをお勧めします。",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "php.ini から open_basedir 設定を削除するか、64bit PHPに切り替えてください。",
@@ -147,28 +168,27 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "%s のバックエンドの共有には、OCP\\Share_Backend インターフェースを実装しなければなりません。",
     "Sharing backend %s not found" : "共有バックエンド %s が見つかりません",
     "Sharing backend for %s not found" : "%s のための共有バックエンドが見つかりません",
-    "%1$s shared »%2$s« with you" : "%1$s は »%2$s« をあなたと共有しました",
-    "%1$s shared »%2$s« with you." : "%1$sが あなたと »%2$s« を共有しました。",
-    "Click the button below to open it." : "開くには下のボタンをクリック",
-    "Open »%s«" : "»%s«を開く",
+    "%1$s shared %2$s with you" : "%1$s は %2$s をあなたと共有しました",
+    "Open %s" : "%sを開く",
     "%1$s via %2$s" : "%1$s via %2$s",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s さんが »%2$s« にノートを追加しました。",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s shared »%2$s« with you and wants to add",
-    "»%s« added a note to a file shared with you" : "»%s« があなたと共有しているファイルにノートを追加しました。 ",
+    "%1$s shared %2$s with you and wants to add:" : "%1$s さんが %2$s にノートを追加しました:",
+    "%1$s shared %2$s with you and wants to add" : "%1$s さんが %2$s にノートを追加しました",
+    "%s added a note to a file shared with you" : "%s があなたと共有しているファイルにノートを追加しました。",
     "Passwords are enforced for link and mail shares" : "リンクとメールの共有にパスワードが強制されます",
-    "SharedWith is not a valid user" : "SharedWithは有効なユーザーではありません",
-    "SharedWith is not a valid group" : "SharedWithは有効なグループではありません",
-    "SharedWith should be empty" : "SharedWithは空でなければなりません",
-    "SharedWith should not be empty" : "SharedWithは空にできません",
-    "SharedWith is not a valid circle" : "SharedWithは有効なサークルではありません",
+    "Share recipient is not a valid user" : "共有先が有効なユーザーではありません",
+    "Share recipient is not a valid group" : "共有先が有効なグループではありません",
+    "Share recipient should be empty" : "共有先は空にする必要があります",
+    "Share recipient should not be empty" : "共有先は空にできません",
+    "Share recipient is not a valid circle" : "共有先が有効なサークルではありません",
     "Unknown share type" : "不明な共有タイプ",
-    "SharedBy should be set" : "SharedByを設定する必要があります",
+    "Share initiator must be set" : "共有イニシエータを設定する必要があります",
     "Cannot share with yourself" : "自分自身とは共有できません",
-    "Path should be set" : "パスを設定する必要があります",
-    "Path should be either a file or a folder" : "パスは、ファイルまたはフォルダーのいずれかでなければなりません",
+    "Shared path must be set" : "共有パスを設定する必要があります",
+    "Shared path must be either a file or a folder" : "共有パスは、ファイルまたはフォルダのいずれかでなければなりません",
     "You cannot share your root folder" : "ルートルートフォルダーを共有することはできません",
     "You are not allowed to share %s" : "%s を共有することを許可されていません。",
-    "A share requires permissions" : "共有には権限が必要です",
+    "Valid permissions are required for sharing" : "共有には有効な権限が必要です",
+    "File shares cannot have create or delete permissions" : "ファイル共有に作成または削除の権限を設定することはできません",
     "Cannot increase permissions of %s" : "%sの権限を追加できません ",
     "Shares need at least read permissions" : "共有には少なくとも読み取り権限が必要です",
     "Files cannot be shared with delete permissions" : "削除権限付きでファイルを共有できません",
@@ -183,10 +203,11 @@ OC.L10N.register(
     "Path is already shared with this group" : "パスはすでにこのグループで共有されています",
     "Link sharing is not allowed" : "リンクの共有は許可されていません",
     "Public upload is not allowed" : "公開アップロードは許可されていません",
-    "Path contains files shared with you" : "パスにはあなたと共有するファイルが含まれています",
+    "You cannot share a folder that contains other shares" : "他の共有を含むフォルダーを共有することはできません",
     "Sharing is disabled" : "共有は無効になっています",
     "Sharing is disabled for you" : "共有は無効になっています",
     "Cannot share with the share owner" : "共有所有者と共有できません",
+    "Share does not have a full ID" : "共有に完全なIDがありません",
     "Cannot change share type" : "共有タイプを変更できません",
     "Can only update recipient on user shares" : "ユーザー共有の受信者のみ更新可能",
     "Cannot enable sending the password by Talk with an empty password" : "空のパスワードでTalkによるパスワード送信を有効にできません",
@@ -194,7 +215,7 @@ OC.L10N.register(
     "Cannot disable sending the password by Talk without setting a new password" : "新しいパスワードを設定しないとTalkによるパスワード送信を無効にできません",
     "Share provider does not support accepting" : "共有プロバイダは受け入れをサポートしていません",
     "Cannot change target of link share" : "リンク共有のターゲットを変更できません",
-    "Invalid recipient" : "無効な受信者",
+    "Invalid share recipient" : "無効な共有先",
     "Group \"%s\" does not exist" : "グループ \"%s\" は存在しません",
     "The requested share does not exist anymore" : "この共有はもう存在しません。",
     "The requested share comes from a disabled user" : "要求された共有は無効化されたユーザーからのものです。",
@@ -254,13 +275,12 @@ OC.L10N.register(
     "A valid Login must be provided" : "ログイン名を提供する必要があります",
     "Login contains whitespace at the beginning or at the end" : "ログイン名の最初か最後に空白が含まれています",
     "Login must not consist of dots only" : "ログイン名はドットのみで構成されてはいけません",
+    "Username is too long" : "ユーザー名が長すぎます",
     "Login is invalid because files already exist for this user" : "このユーザのファイルが既に存在するため、このログイン名は使用できません",
     "Account disabled" : "アカウントは無効",
     "Login canceled by app" : "アプリによりログインが中止されました",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "次の依存関係を満たしていないため、アプリ \"%1$s\" をインストールできません: %2$s",
     "a safe home for all your data" : "すべてのデータを安全に保管します",
-    "File is currently busy, please try again later" : "現在ファイルはビジーです。後でもう一度試してください。",
-    "Cannot download file" : "ファイルをダウンロードできません",
     "Application is not enabled" : "アプリケーションは無効です",
     "Authentication error" : "認証エラー",
     "Token expired. Please reload page." : "トークンが無効になりました。ページを再読込してください。",
@@ -268,8 +288,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "\"config\" ディレクトリに書き込みできません",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "これは通常、Webサーバーの configディレクトリ に書き込み権限を与えることで解決できます。%s を見てください",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "またはconfig.phpファイルを読み取り専用にしたい場合は、オプション \"config_is_read_only\"をtrueに設定してください。 詳しくは%sを確認してください。",
-    "Cannot write into \"apps\" directory." : "\"apps\" ディレクトリに書き込みができません",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "これは通常、Webサーバーにappsディレクトリへの書き込み権限を許可するか、構成ファイルでAppStoreを無効にすることで解決できます。",
     "Cannot create \"data\" directory." : "dataディレクトリを作成できません。",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "これは通常、ウェブサーバーにルートディレクトリへの書き込み権限を与えることで解決できます。詳しくは%sを確認してください。",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Webサーバーのルートディレクトリに書き込み権限パーミッションが必要です。詳しくは%sを確認してください。",
@@ -305,12 +323,49 @@ OC.L10N.register(
     "Storage connection error. %s" : "ストレージへの接続エラー｡ %s",
     "Storage is temporarily not available" : "ストレージは一時的に利用できません",
     "Storage connection timeout. %s" : "ストレージへの接続がタイムアウト。 %s",
+    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "このチェックを実行させるには、Webサーバーが自分自身に接続できることを確認しなければならない。そのため、少なくとも一つの `trusted_domains` または `overwrite.cli.url` を解決して接続できなければなりません。この失敗は、サーバ側のDNSの不一致やアウトバウンドファイアウォールルールの結果かもしれません。",
+    "Analyze images" : "画像を分析する",
+    "Ask a question about the given images." : "与えられた画像について質問してください。",
+    "Images" : "画像",
+    "Images to ask a question about" : "質問したい画像",
+    "Question" : "質問",
+    "What to ask about the images." : "画像について質問すべきこと。",
+    "Generated response" : "生成された応答",
+    "The answer to the question" : "質問への回答",
+    "Audio chat" : "音声チャット",
+    "Voice chat with the assistant" : "アシスタントとの音声チャット",
+    "System prompt" : "システムプロンプト",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "会話中にアシスタントが従うべきルールと前提条件を定義します。",
+    "Chat voice message" : "チャット音声メッセージ",
+    "Describe a task that you want the assistant to do or ask a question." : "アシスタントに実行してほしいタスクを説明するか質問を投げかけてください。",
+    "Chat history" : "チャット履歴",
+    "The history of chat messages before the current message, starting with a message by the user." : "現在のメッセージ以前に送信されたチャットメッセージの履歴で、ユーザーが送信したメッセージから始まるもの。",
+    "Input transcript" : "文字起こしを入力",
+    "Transcription of the audio input" : "音声入力の文字起こし",
+    "Response voice message" : "応答音声メッセージ",
+    "The generated voice response as part of the conversation" : "会話の一部として生成された音声応答",
+    "Output transcript" : "文字起こしを出力",
+    "Transcription of the audio output" : "音声出力の文字起こし",
     "Transcribe audio" : "音声の書き起こし",
     "Transcribe the things said in an audio" : "音声で言ったことを書き起こす",
     "Audio input" : "音声入力",
     "The audio to transcribe" : "文字起こしする音声",
     "Transcription" : "書き起こし",
     "The transcribed text" : "書き起こされたテキスト",
+    "Chat by voice with an agent" : "エージェントと音声でチャットする",
+    "Describe a task that you want the agent to do or ask a question." : "エージェントに実行してほしいタスクを説明するか質問を投げかけてください。エージェントと音声でチャットできます。",
+    "Confirmation" : "確認",
+    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "以前に要求されたアクションを承認するかどうか： 0なら拒否、1なら承認。",
+    "Conversation token" : "会話トークン",
+    "A token representing the conversation." : "会話を表すトークン。",
+    "The new conversation token" : "新しい会話トークン",
+    "Send this along with the next interaction." : "次の交流と一緒にこれを送る。",
+    "Requested actions by the agent" : "エージェントが要求するアクション",
+    "Actions that the agent would like to carry out in JSON format." : "エージェントが JSON 形式で実行したいアクション。",
+    "Chat with an agent" : "エージェントとチャット",
+    "Chat message" : "チャットメッセージ",
+    "A chat message to send to the agent." : "エージェントに送信するチャットメッセージ。",
+    "The response from the chat model." : "チャットモデルからの応答。",
     "Context write" : "コンテキストを書く",
     "Writes text in a given style based on the provided source material." : "提供されたソース資料に基づいて、指定されたスタイルでテキストを作成します。",
     "Writing style" : "文体",
@@ -332,20 +387,36 @@ OC.L10N.register(
     "How many images to generate" : "生成する画像の数",
     "Output images" : "出力画像",
     "The generated images" : "生成された画像",
+    "Generate speech" : "スピーチの生成",
+    "Generate speech from a transcript" : "原稿からスピーチを生成する",
+    "Write transcript that you want the assistant to generate speech from" : "アシスタントに音声を生成させたい原稿を書きます",
+    "Output speech" : "スピーチの出力",
+    "The generated speech" : "生成されたスピーチ",
     "Free text to text prompt" : "フリーテキストからテキストへのプロンプト",
     "Runs an arbitrary prompt through a language model that returns a reply" : "応答を返す言語モデルを通じて任意のプロンプトを実行します",
     "Describe a task that you want the assistant to do or ask a question" : "アシスタントに実行してほしいタスクまたは質問を記述します",
     "Generated reply" : "生成された返信",
     "The generated text from the assistant" : "アシスタントから生成されたテキスト",
+    "Change Tone" : "トーンを変更",
+    "Change the tone of a piece of text." : "文章のトーンを変更する。",
+    "Write a text that you want the assistant to rewrite in another tone." : "アシスタントに別のトーンで書き直してもらいたい文章を書く。",
+    "Desired tone" : "希望するトーン",
+    "In which tone should your text be rewritten?" : "どのトーンで書き直すべきか？",
+    "The rewritten text in the desired tone, written by the assistant:" : "アシスタントが書き直した、希望するトーンの文章：",
     "Chat" : "チャット",
     "Chat with the assistant" : "アシスタントとチャット",
-    "System prompt" : "システムプロンプト",
-    "Define rules and assumptions that the assistant should follow during the conversation." : "会話中にアシスタントが従うべきルールと前提条件を定義します。",
-    "Chat message" : "チャットメッセージ",
-    "Chat history" : "チャット履歴",
     "The history of chat messages before the current message, starting with a message by the user" : "ユーザーのメッセージから始まる、現在のメッセージより前のチャットメッセージの履歴",
     "Response message" : "応答メッセージ",
     "The generated response as part of the conversation" : "会話の一部として生成された応答",
+    "Chat with tools" : "ツールでチャット",
+    "Chat with the language model with tool calling support." : "ツール呼び出しサポートを使用して言語モデルとチャット。",
+    "Tool message" : "ツールメッセージ",
+    "The result of tool calls in the last interaction" : "直近のインタラクションにおけるツール呼び出しの結果",
+    "Available tools" : "利用可能なツール",
+    "The available tools in JSON format" : "JSON形式で利用可能なツール",
+    "The response from the chat model" : "チャットモデルからの応答",
+    "Tool calls" : "ツールコール",
+    "Tools call instructions from the model in JSON format" : "JSON形式のモデルからのツール呼び出し命令",
     "Formalize text" : "テキストの形式化",
     "Takes a text and makes it sound more formal" : "テキストを使用して、よりフォーマルに聞こえるようにします",
     "Write a text that you want the assistant to formalize" : "アシスタントに形式化してもらいたいテキストを入力します",
@@ -356,6 +427,12 @@ OC.L10N.register(
     "Original text" : "原文",
     "The original text to generate a headline for" : "見出しを生成する元のテキスト",
     "The generated headline" : "生成された見出し",
+    "Proofread" : "校正",
+    "Proofreads a text and lists corrections" : "文章を校正し、訂正箇所をリストアップする",
+    "Text" : "テキスト",
+    "The text to proofread" : "校正するテキスト",
+    "Corrections" : "修正",
+    "The corrections that should be made in your text" : "テキストに加えるべき修正",
     "Reformulate text" : "テキストを書き直す",
     "Takes a text and reformulates it" : "テキストを受け取り、それを書き直す",
     "Write a text that you want the assistant to reformulate" : "アシスタントに書き直してもらいたいテキストを入力します",
@@ -391,33 +468,11 @@ OC.L10N.register(
     "Generate headline" : "見出しの生成",
     "Summarizes text by reducing its length without losing key information." : "重要な情報を失わずにテキストの長さを要約して短縮する。",
     "Extracts topics from a text and outputs them separated by commas." : "テキストからトピックを抽出し、カンマ区切りで出力します。",
-    "Education Edition" : "教育向けエディション",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "この設定にアクセスするには、ログインしたユーザーが管理者、サブ管理者、または特別な権利が必要です。",
-    "Logged in user must be an admin or sub admin" : "ログインユーザーは管理者またはサブ管理者である必要があります",
-    "Logged in user must be an admin" : "ログインユーザーは管理者である必要があります",
-    "File name is a reserved word" : "ファイル名が予約された単語です",
-    "File name contains at least one invalid character" : "ファイル名に1文字以上の無効な文字が含まれています",
-    "File name is too long" : "ファイル名が長すぎます",
-    "Help" : "ヘルプ",
-    "Users" : "ユーザー",
-    "Unknown user" : "不明なユーザー",
-    "Enter the database username and name for %s" : "%sのデータベース名とユーザー名を入力してください",
-    "Enter the database username for %s" : "%sのデータベースのユーザー名を指定してください",
-    "MySQL username and/or password not valid" : "MySQLのユーザー名またはパスワードが有効ではありません",
-    "Oracle username and/or password not valid" : "Oracleのユーザー名またはパスワードが有効ではありません",
-    "PostgreSQL username and/or password not valid" : "PostgreSQLのユーザー名またはパスワードが有効ではありません",
-    "Set an admin username." : "管理者のユーザー名を設定",
-    "Sharing %s failed, because this item is already shared with user %s" : "このアイテム%sはすでにユーザー%sと共有されているため、共有に失敗しました",
-    "The username is already being used" : "このユーザー名はすでに使われています",
-    "Could not create user" : "ユーザーを作成できませんでした",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "ユーザー名で利用できる文字列： \"a-z\", \"A-Z\", \"0-9\", スペース, \"_.@-\"",
-    "A valid username must be provided" : "有効なユーザー名を指定する必要があります",
-    "Username contains whitespace at the beginning or at the end" : "ユーザー名の最初か最後に空白が含まれています",
-    "Username must not consist of dots only" : "ユーザー名に、ドットのみはつけられません",
-    "Username is invalid because files already exist for this user" : "このユーザーのファイルが既に存在するため、このユーザー名は使用できません",
-    "User disabled" : "ユーザーは無効です",
-    "Your data directory is readable by other users." : "データディレクトリは他のユーザーからも読み取ることができます",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "ディレクトリが他のユーザーから見えないように、パーミッションを 0770 に変更してください。",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "データディレクトリの直下に \".ocdata\" ファイルがあるのを確認してください。"
+    "Organisation" : "組織",
+    "File is currently busy, please try again later" : "現在ファイルはビジーです。後でもう一度試してください。",
+    "Cannot download file" : "ファイルをダウンロードできません",
+    "Cannot write into \"apps\" directory." : "\"apps\" ディレクトリに書き込みができません",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "これは通常、Webサーバーにappsディレクトリへの書き込み権限を許可するか、構成ファイルでAppStoreを無効にすることで解決できます。",
+    "Login is too long" : "ログインが長すぎます"
 },
 "nplurals=1; plural=0;");
